#!/bin/bash -e

apt-get update
dpkg --purge --force-depends ca-certificates-java
apt-get install ca-certificates-java

if [ $JAVA_VERSION = "17" ]
then
  GRADLE_VERSION="8.3"
else
  GRADLE_VERSION="6.9.4"
fi
echo "================ Installing gradle "$GRADLE_VERSION"  ================="
wget -nv https://services.gradle.org/distributions/gradle-$GRADLE_VERSION-all.zip
unzip -qq gradle-$GRADLE_VERSION-all.zip -d /usr/local && rm -f gradle-$GRADLE_VERSION-all.zip
ln -fs /usr/local/gradle-$GRADLE_VERSION/bin/gradle /usr/bin
echo "export PATH=$PATH:/usr/local/gradle-$GRADLE_VERSION/bin" >> /etc/drydock/.env

APACHE_MAVEN="3.8.5"
echo "================ Installing apache-maven "$APACHE_MAVEN" ================="
wget -nv https://archive.apache.org/dist/maven/maven-3/$APACHE_MAVEN/binaries/apache-maven-$APACHE_MAVEN-bin.tar.gz
tar xzf apache-maven-$APACHE_MAVEN-bin.tar.gz -C /usr/local && rm -f apache-maven-$APACHE_MAVEN-bin.tar.gz
ln -fs /usr/local/apache-maven-$APACHE_MAVEN/bin/mvn /usr/bin
echo "export PATH=$PATH:/usr/local/apache-maven-$APACHE_MAVEN/bin" >> /etc/drydock/.env
echo "export M2_HOME=/usr/local/apache-maven-$APACHE_MAVEN/" >> /etc/drydock/.env

APACHE_ANT="1.10.14"
echo "================ Installing apache-ant "$APACHE_ANT" ================="
wget -nv https://archive.apache.org/dist/ant/binaries/apache-ant-$APACHE_ANT-bin.tar.gz
tar xzf apache-ant-$APACHE_ANT-bin.tar.gz -C /usr/local && rm -f apache-ant-$APACHE_ANT-bin.tar.gz
ln -fs /usr/local/apache-ant-$APACHE_ANT/bin/ant /usr/bin
echo "export ANT_HOME=/usr/local/apache-ant-$APACHE_ANT" >> /etc/drydock/.env
echo "export PATH=$PATH:/usr/local/apache-ant-$APACHE_ANT/bin" >> /etc/drydock/.env

echo "deb http://security.ubuntu.com/ubuntu bionic main restricted universe multiverse" >> /etc/apt/sources.list
echo "deb http://security.ubuntu.com/ubuntu bionic-security main restricted universe multiverse" >> /etc/apt/sources.list
apt-get update

echo "================ Installing openjdk-"$JAVA_VERSION"-jdk ================="

if [ "$JAVA_VERSION" = "8" ]
then
  apt-get install -y openjdk-"$JAVA_VERSION"-jdk
  sudo update-alternatives --install /usr/bin/java java /usr/lib/jvm/java-8-openjdk-amd64/bin/java 1
  sudo update-alternatives --install /usr/bin/javac javac /usr/lib/jvm/java-8-openjdk-amd64/bin/javac 1
  sudo update-alternatives --set java /usr/lib/jvm/java-8-openjdk-amd64/bin/java
  sudo update-alternatives --set javac /usr/lib/jvm/java-8-openjdk-amd64/bin/javac
elif [ "$JAVA_VERSION" = "11" ]
then
  sudo add-apt-repository ppa:openjdk-r/ppa
  sudo apt-get update
  sudo apt install -y openjdk-"$JAVA_VERSION"-jdk
elif [ "$JAVA_VERSION" = "17" ]
then
  wget -O- https://apt.corretto.aws/corretto.key | sudo apt-key add -
  sudo add-apt-repository 'deb https://apt.corretto.aws stable main'
  sudo apt-get update && sudo apt-get install java-common
  sudo apt-get update; sudo apt-get install -y java-17-amazon-corretto-jdk
fi
